@@ -1548,6 +1548,7 @@ ssize_t UDPSocket::send(const void *buf, size_t len)
 ssize_t UDPSocket::receive(void *buf, size_t len, bool reply)
 {
 	struct sockaddr *addr;
+	struct sockaddr_in senderAddress;  // DMC 2/7/05 ADD for use below.
 	socklen_t alen;
 
 	switch(family)
@@ -1565,19 +1566,51 @@ ssize_t UDPSocket::receive(void *buf, size_t len, bool reply)
 
 	if(isConnected() || !reply)
 	{
-		addr = NULL;
-		alen = 0;
+		// DMC 2/7/05 MOD to use senderAddress instead of NULL, to prevent 10014 error
+		// from recvfrom.
+		//addr = NULL;
+		//alen = 0;
+		addr = (struct sockaddr*)(&senderAddress);
+		alen = sizeof(struct sockaddr_in);
 	}
 	
-	return _IORET64 ::recvfrom(so, (char *)buf, _IOLEN64 len, 0, addr, &alen);
+	int bytes = ::recvfrom(so, (char *)buf, _IOLEN64 len, 0, addr, &alen);
+
+#ifdef	WIN32
+	int code = 0;
+
+	if (bytes == SOCKET_ERROR)
+	{
+		code = WSAGetLastError();
+	}
+#endif
+
+	return _IORET64 bytes;
 }
 
 Socket::Error UDPSocket::join(const IPV4Multicast &ia,int InterfaceIndex)
 {
-#ifndef WIN32
-#if defined(IP_ADD_MEMBERSHIP) && defined(SIOCGIFINDEX) && !defined(__FreeBSD__) && !defined(_OSF_SOURCE) && !defined(__hpux)
 
-        struct ip_mreqn      group;
+#ifdef WIN32
+		
+		// DMC 2/7/05: Added WIN32 block.  Win32 does not define the ip_mreqn structure,
+		// so we must use ip_mreq with INADDR_ANY.
+		struct ip_mreq      group;
+        struct sockaddr_in   myaddr;
+        socklen_t            len = sizeof(myaddr);
+
+        if(!flags.multicast)
+          return error(errMulticastDisabled);
+
+        getsockname(so, (struct sockaddr *)&myaddr, &len);  
+        group.imr_multiaddr.s_addr = ia.getAddress().s_addr;
+        group.imr_interface.s_addr = INADDR_ANY;
+		int retval = setsockopt(so, IPPROTO_IP, IP_ADD_MEMBERSHIP, (char *)&group, sizeof(group));
+		return errSuccess;
+
+#elif defined(IP_ADD_MEMBERSHIP) && defined(SIOCGIFINDEX) && !defined(__FreeBSD__) && !defined(_OSF_SOURCE) && !defined(__hpux)
+        
+		struct ip_mreqn      group;
         struct sockaddr_in   myaddr;
         socklen_t            len = sizeof(myaddr);
 
@@ -1593,9 +1626,6 @@ Socket::Error UDPSocket::join(const IPV4Multicast &ia,int InterfaceIndex)
 #else
         return error(errServiceUnavailable);
 #endif
-#else
-	return error(errServiceUnavailable);
-#endif // WIN32
 }
 
 
@@ -2688,7 +2718,7 @@ void TCPStream::connect(const IPV6Host &host, tpport_t port, unsigned mss)
 			
 			// timeout check for connect completion
 
-			if(::select(((int)(so)) + 1, NULL, &fds, NULL, &to) < 1)
+			if(::select((int)so + 1, NULL, &fds, NULL, &to) < 1)
 				continue;
 
 			getsockopt(so, SOL_SOCKET, SO_ERROR, (char *)&sockopt, &len);
@@ -3123,7 +3153,7 @@ int TCPStream::overflow(int c)
 
 TCPSession::TCPSession(const IPV4Host &ia, 
 		       tpport_t port, size_t size, int pri, size_t stack) :
-TCPStream(IPV4), Thread(pri, stack)
+Thread(pri, stack), TCPStream(IPV4)
 {
 	setCompletion(false);
 	setError(false);
@@ -3170,7 +3200,7 @@ TCPStream(IPV4), Thread(pri, stack)
 #ifdef  CCXX_IPV6
 TCPSession::TCPSession(const IPV6Host &ia, 
 		       tpport_t port, size_t size, int pri, size_t stack) :
-TCPStream(IPV6), Thread(pri, stack)
+Thread(pri, stack), TCPStream(IPV6)
 {
 	setCompletion(false);
 	setError(false);
@@ -3217,7 +3247,7 @@ TCPStream(IPV6), Thread(pri, stack)
 
 
 TCPSession::TCPSession(TCPSocket &s, int pri, size_t stack) :
-TCPStream(s), Thread(pri, stack)
+Thread(pri, stack), TCPStream(s)
 {
 	setCompletion(true);
 	setError(false);
@@ -3225,13 +3255,19 @@ TCPStream(s), Thread(pri, stack)
 
 #ifdef  CCXX_IPV6
 TCPSession::TCPSession(TCPV6Socket &s, int pri, size_t stack) :
-TCPStream(s), Thread(pri, stack)
+Thread(pri, stack), TCPStream(s)
 {
 	setCompletion(true);
 	setError(false);
 }
 #endif
 
+TCPSession::~TCPSession()
+{
+	terminate();
+	endStream();
+}
+
 int TCPSession::waitConnection(timeout_t timer)
 {
 	long sockopt = 0;
