@@ -1,4 +1,4 @@
-// Copyright (C) 1999-2003 Open Source Telecom Corporation.
+// Copyright (C) 1999-2005 Open Source Telecom Corporation.
 //  
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -14,29 +14,26 @@
 // along with this program; if not, write to the Free Software 
 // Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 // 
-// As a special exception to the GNU General Public License, permission is 
-// granted for additional uses of the text contained in its release 
-// of Common C++.
-// 
-// The exception is that, if you link the Common C++ library with other
-// files to produce an executable, this does not by itself cause the
-// resulting executable to be covered by the GNU General Public License.
-// Your use of that executable is in no way restricted on account of
-// linking the Common C++ library code into it.
+// As a special exception, you may use this file as part of a free software
+// library without restriction.  Specifically, if other files instantiate
+// templates or use macros or inline functions from this file, or you compile
+// this file and link it with other files to produce an executable, this
+// file does not by itself cause the resulting executable to be covered by
+// the GNU General Public License.  This exception does not however    
+// invalidate any other reasons why the executable file might be covered by
+// the GNU General Public License.    
 //
-// This exception does not however invalidate any other reasons why
-// the executable file might be covered by the GNU General Public License.
-//
-// This exception applies only to the code released under the 
-// name Common C++.  If you copy code from other releases into a copy of
+// This exception applies only to the code released under the name GNU
+// Common C++.  If you copy code from other releases into a copy of GNU
 // Common C++, as the General Public License permits, the exception does
 // not apply to the code that you add in this way.  To avoid misleading
 // anyone as to the status of such modified files, you must delete
 // this exception notice from them.
-// 
-// If you write modifications of your own for Common C++, it is your choice
+//
+// If you write modifications of your own for GNU Common C++, it is your choice
 // whether to permit this exception to apply to your modifications.
 // If you do not wish that, delete this exception notice.
+//
 
 #include <cc++/config.h>
 #include <cc++/export.h>
@@ -128,7 +125,7 @@ typedef	unsigned (__stdcall *exec_t)(void *);
 #define CCXX_SUSPEND_MODE_ONE_SIGNAL 3
 #define	CCXX_SUSPEND_MODE_MACH 4
 
-#if defined(_THR_MACH)
+#if defined(_THR_MACH) && !defined(_DARWIN6_)
 #define	CCXX_SUSPEND_MODE CCXX_SUSPEND_MODE_MACH
 #elif defined(HAVE_PTHREAD_SUSPEND)
 #define CCXX_SUSPEND_MODE CCXX_SUSPEND_MODE_NOT_RECURSIVE
@@ -762,6 +759,23 @@ void Thread::setName(const char *text)
 		snprintf(_name, sizeof(_name), "%ld", (long)getId());
 }	
 
+void Thread::initial(void)
+{
+}
+
+void Thread::final(void)
+{
+}
+
+void *Thread::getExtended(void)
+{
+	return NULL;
+}
+
+void Thread::notify(Thread *)
+{
+}
+
 bool Thread::isThread(void)
 {
 	if(!priv)
@@ -1517,6 +1531,31 @@ PosixThread::PosixThread(int pri, size_t stack):
        SysTime::getTime(&_alarm);
 }
 
+void PosixThread::onTimer(void)
+{
+}
+
+void PosixThread::onHangup(void)
+{
+}
+
+void PosixThread::onException(void)
+{
+}
+
+void PosixThread::onDisconnect(void)
+{
+}
+
+void PosixThread::onPolling(void)
+{
+}
+
+void PosixThread::onSignal(int sig)
+{
+}
+
+
 void PosixThread::setTimer(timeout_t timer, bool periodic)
 {
 	sigset_t sigs;
