@@ -478,7 +478,7 @@ UnixStream::UnixStream(UnixSocket &server, int size, bool throwflag, timeout_t t
  }
 
  UnixSession::UnixSession(const char* pathname, int size, int pri, int stack) :
- UnixStream(), Thread(pri, stack)
+ Thread(pri, stack), UnixStream()
  {
         struct sockaddr_un addr;
 	unsigned slen = strlen(pathname);
@@ -524,12 +524,18 @@ UnixStream::UnixStream(UnixSocket &server, int size, bool throwflag, timeout_t t
 
 
  UnixSession::UnixSession(UnixSocket &s,int size, int pri, int stack) :
- UnixStream(s, size), Thread(pri, stack)
+ Thread(pri, stack), UnixStream(s, size)
  {
  	setCompletion(true);
  	setError(false);
  }
 
+ UnixSession::~UnixSession()
+ {
+	terminate();
+	endStream();
+ }
+
  int UnixSession::waitConnection(timeout_t timeout)
  {
  	long sockopt = 0;
